@@ -1,39 +1,34 @@
+from __future__ import annotations
+
 import logging
-from typing import List, Optional
+from typing import TYPE_CHECKING, List, Optional, Type
 
 from django.apps import apps as django_apps
 from django.conf import settings
-from django.core.exceptions import (
-    MultipleObjectsReturned,
-    ObjectDoesNotExist,
-    ValidationError,
-)
+from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist
 from django.core.management.color import color_style
 from django.db import models
 from django.utils.formats import localize
 from edc_constants.constants import CLOSED, NEW, OPEN
 from edc_model.constants import DEFAULT_BASE_FIELDS
+from edc_sites.utils import valid_site_for_subject_or_raise
 
 from edc_action_item.stubs import ActionItemStub
 
 from .create_action_item import SingletonActionItemError, create_action_item
+from .exceptions import ActionError
 from .get_action_type import get_action_type
 from .site_action_items import site_action_items
 
+if TYPE_CHECKING:
+    from .models import ActionItem, ActionType
+
 logger = logging.getLogger(__name__)
 style = color_style()
 
 REFERENCE_MODEL_ERROR_CODE = "reference_model"
 
 
-class ActionError(ValidationError):
-    pass
-
-
-class RelatedReferenceObjectDoesNotExist(ObjectDoesNotExist):
-    pass
-
-
 class Action:
     admin_site_name: str = None
     color_style: str = "danger"
@@ -59,9 +54,7 @@ class Action:
 
     action_item_model: str = "edc_action_item.actionitem"
     action_type_model: str = "edc_action_item.actiontype"
-    next_actions: Optional[
-        List[str]
-    ] = None  # a list of Action classes which may include 'self'
+    next_actions: list[str] | None = None  # a list of Action classes which may include 'self'
 
     def __init__(
         self,
@@ -74,7 +67,6 @@ class Action:
         using: Optional[str] = None,
         readonly: Optional[bool] = None,
     ) -> None:
-
         self._action_item = action_item
         self._reference_obj = reference_obj
 
@@ -118,9 +110,9 @@ class Action:
         if not self.related_action_item and self.related_reference_fk_attr:
             raise ActionError(
                 "Action class expects a related_action_item. "
-                f"related_reference_fk_attr={self.related_reference_fk_attr}. "
-                f"Got None for action based on action_item {self.action_item}. "
-                f"See {repr(self)}"
+                f"related_reference_fk_attr=`{self.related_reference_fk_attr}`. "
+                f"Got None for action based on action_item `{self.action_item}`. "
+                f"See `{repr(self)}`"
             )
 
         if self.reference_obj and not self.readonly:
@@ -168,7 +160,7 @@ class Action:
                     and self.action_item.status == CLOSED
                 ):
                     self.action_item.status = OPEN
-                    self.action_item.save(using=self.using)
+                    self.action_item.save(update_fields=["status"], using=self.using)
                     self.action_item.refresh_from_db()
         return self._reference_obj
 
@@ -224,14 +216,16 @@ class Action:
                 raise ActionError(f"Unable to get or create ActionItem. Got {opts}.")
         return self._action_item
 
-    def _create_new_action_item(self, **opts):
+    def _create_new_action_item(self, subject_identifier: str = None, **opts):
         """Create a new action item.
 
         Called only after checking.
         """
+        valid_site_for_subject_or_raise(subject_identifier)
         try:
             self._action_item = create_action_item(
                 self.__class__,
+                subject_identifier=subject_identifier,
                 parent_action_item=self.parent_action_item,
                 priority=self.get_priority(),
                 using=self.using,
@@ -248,12 +242,12 @@ class Action:
             )
 
     @classmethod
-    def action_item_model_cls(cls):
+    def action_item_model_cls(cls) -> Type[ActionItem]:
         """Returns the ActionItem model class."""
         return django_apps.get_model(cls.action_item_model)
 
     @classmethod
-    def action_type_model_cls(cls):
+    def action_type_model_cls(cls) -> Type[ActionType]:
         """Returns the ActionType model class."""
         return django_apps.get_model(cls.action_type_model)
 
