@@ -2,7 +2,7 @@ from typing import List
 
 from django.core.exceptions import ObjectDoesNotExist
 from edc_constants.constants import CLOSED, NEW, OPEN
-from edc_notification import Notification
+from edc_notification.notification import Notification
 from edc_utils import get_utcnow
 
 NOTIFY_ON_NEW_AND_NO_REFERENCE_OBJ = "notify_on_new_and_no_reference_obj"
@@ -12,10 +12,6 @@ NOTIFY_ON_CLOSE = "notify_on_closed"
 NOTIFY_ON_CHANGED_REFERENCE_OBJ = "notify_on_changed_reference_obj"
 
 
-class ActionItemNotificationError(Exception):
-    pass
-
-
 class ActionItemNotification(Notification):
     """A Notification class for the action item model.
 
