@@ -1,36 +1,39 @@
+from __future__ import annotations
+
 from datetime import datetime
-from typing import Any, Optional, Type
+from typing import TYPE_CHECKING, Type
 
 from django.apps import apps as django_apps
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.db.models.deletion import PROTECT
-from edc_constants.constants import NEW
+from edc_constants.constants import CANCELLED, NEW
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
 from edc_model.models import BaseUuidModel, HistoricalRecords
 from edc_notification.model_mixins import NotificationModelMixin
-from edc_sites.models import CurrentSiteManager as BaseCurrentSiteManager
-from edc_sites.models import SiteModelMixin
+from edc_sites.managers import CurrentSiteManager as BaseCurrentSiteManager
+from edc_sites.model_mixins import SiteModelMixin
 from edc_utils import get_utcnow
 
-from edc_action_item.stubs import ActionStub
-
 from ..choices import ACTION_STATUS, PRIORITY
+from ..exceptions import ActionItemStatusError, SubjectDoesNotExist
 from ..identifiers import ActionIdentifier
 from ..site_action_items import site_action_items
 from .action_type import ActionType
 
+if TYPE_CHECKING:
+    from edc_crf.model_mixins import CrfModelMixin
 
-class ActionItemUpdatesRequireFollowup(Exception):
-    pass
+    from ..action import Action
 
+    class PrnModel(BaseUuidModel):
+        subject_identifier: str
+        ...
 
-class SubjectDoesNotExist(Exception):
-    pass
+    class CrfModel(CrfModelMixin): ...
 
 
 class CurrentSiteManager(BaseCurrentSiteManager):
-
     use_in_migrations = True
 
     def get_by_natural_key(self, action_identifier):
@@ -38,7 +41,6 @@ class CurrentSiteManager(BaseCurrentSiteManager):
 
 
 class ActionItemManager(models.Manager):
-
     use_in_migrations = True
 
     def get_by_natural_key(self, action_identifier):
@@ -51,7 +53,6 @@ class ActionItem(
     NotificationModelMixin,
     BaseUuidModel,
 ):
-
     subject_identifier_model = "edc_registration.registeredsubject"
 
     action_identifier = models.CharField(max_length=50, unique=True)
@@ -62,12 +63,6 @@ class ActionItem(
         ActionType, on_delete=PROTECT, related_name="action_type", verbose_name="Action"
     )
 
-    reference_model = models.CharField(
-        max_length=50,
-        null=True,
-        help_text="model name in label_lower format",
-    )
-
     linked_to_reference = models.BooleanField(
         default=False,
         editable=False,
@@ -82,7 +77,7 @@ class ActionItem(
         ),
     )
 
-    related_reference_model = models.CharField(max_length=100, null=True, editable=False)
+    # related_reference_model = models.CharField(max_length=100, null=True, editable=False)
 
     related_action_identifier = models.CharField(
         max_length=50,
@@ -140,13 +135,13 @@ class ActionItem(
 
     auto_created_comment = models.CharField(max_length=25, null=True, blank=True)
 
-    on_site = CurrentSiteManager()
-
     objects = ActionItemManager()
 
+    on_site = CurrentSiteManager()
+
     history = HistoricalRecords()
 
-    def __str__(self):
+    def __str__(self) -> str:
         return (
             f"{self.action_type.display_name} {self.action_identifier[-9:]} "
             f"for {self.subject_identifier} ({self.get_status_display()})"
@@ -172,29 +167,37 @@ class ActionItem(
                     f"Got '{self.subject_identifier}'."
                 )
             self.priority = self.priority or self.action_type.priority
-            self.reference_model = self.action_type.reference_model
-            self.related_reference_model = self.action_type.related_reference_model
-            self.instructions = self.action_type.instructions
+        else:
+            if (
+                self.status in [NEW, CANCELLED]
+                and django_apps.get_model(self.reference_model)
+                .objects.filter(action_identifier=self.action_identifier)
+                .exists()
+            ):
+                raise ActionItemStatusError(
+                    "Invalid action item status. Reference model exists. "
+                    f"Got `{self.get_status_display()}`. Perhaps catch this in the form"
+                )
         super().save(*args, **kwargs)
 
-    def natural_key(self) -> tuple:
+    def natural_key(self) -> tuple[str]:
         return (self.action_identifier,)  # noqa
 
     @property
-    def last_updated(self) -> Optional[datetime]:
+    def last_updated(self) -> datetime | str:
         return None if self.status == NEW else self.modified
 
     @property
-    def user_last_updated(self) -> Optional[str]:
+    def user_last_updated(self) -> str | None:
         return None if self.status == NEW else self.user_modified or self.user_created
 
     @property
-    def action_cls(self) -> Type[ActionStub]:
+    def action_cls(self) -> Type[Action]:
         """Returns the action_cls."""
         return site_action_items.get(self.action_type.name)
 
     @property
-    def action(self) -> ActionStub:
+    def action(self) -> Action:
         """Returns the instantiated action_cls."""
         return self.action_cls(
             subject_identifier=self.subject_identifier,
@@ -203,15 +206,19 @@ class ActionItem(
         )
 
     @property
-    def reference_model_cls(self) -> Type[BaseUuidModel]:
-        return django_apps.get_model(self.reference_model)
+    def reference_model(self) -> str:
+        return self.action_type.reference_model
 
     @property
-    def reference_obj(self) -> Any:
+    def reference_model_cls(self) -> Type[PrnModel | CrfModel]:
+        return django_apps.get_model(self.action_type.reference_model)
+
+    @property
+    def reference_obj(self) -> PrnModel | CrfModel:
         return self.reference_model_cls.objects.get(action_identifier=self.action_identifier)
 
     @property
-    def parent_reference_obj(self: Any) -> Any:
+    def parent_reference_obj(self) -> PrnModel | CrfModel:
         if not self.parent_action_item:
             raise ObjectDoesNotExist(
                 f"Parent ActionItem does not exist for {self.action_identifier}."
@@ -219,7 +226,11 @@ class ActionItem(
         return self.parent_action_item.reference_obj
 
     @property
-    def related_reference_obj(self) -> BaseUuidModel:
+    def related_reference_model(self) -> str:
+        return self.action_type.related_reference_model
+
+    @property
+    def related_reference_obj(self) -> PrnModel | CrfModel:
         if not self.related_action_item:
             raise ObjectDoesNotExist(
                 f"Related ActionItem does not exist for {self.action_identifier}."
@@ -231,17 +242,33 @@ class ActionItem(
         """Returns a shortened action identifier."""
         return self.action_identifier[-9:]
 
-    class Meta(BaseUuidModel.Meta):
+    @property
+    def display_name(self) -> str:
+        return self.action_type.display_name
+
+    @property
+    def label_color(self) -> str:
+        return self.action_cls.color_style
+
+    class Meta(
+        BaseUuidModel.Meta,
+        NonUniqueSubjectIdentifierFieldMixin.Meta,
+    ):
         verbose_name = "Action Item"
         verbose_name_plural = "Action Items"
-        indexes = [
-            models.Index(
-                fields=[
-                    "id",
-                    "action_identifier",
-                    "action_type",
-                    "status",
-                    "report_datetime",
-                ]
-            )
-        ]
+        indexes = (
+            BaseUuidModel.Meta.indexes
+            + NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
+            + [
+                models.Index(
+                    fields=[
+                        "subject_identifier",
+                        "action_identifier",
+                        "action_type",
+                        "site_id",
+                        "status",
+                        "report_datetime",
+                    ],
+                ),
+            ]
+        )
