@@ -14,7 +14,6 @@ class ReferenceManager(models.Manager):
 
 
 class Reference(NonUniqueSubjectIdentifierFieldMixin, ActionModelMixin, BaseUuidModel):
-
     """Model used as a default reference model for simple actions
     not created by another model.
 
@@ -35,5 +34,7 @@ class Reference(NonUniqueSubjectIdentifierFieldMixin, ActionModelMixin, BaseUuid
     def natural_key(self):
         return (self.action_identifier,)  # noqa
 
-    class Meta(BaseUuidModel.Meta):
-        pass
+    class Meta(BaseUuidModel.Meta, NonUniqueSubjectIdentifierFieldMixin.Meta):
+        indexes = (
+            BaseUuidModel.Meta.indexes + NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
+        )
