@@ -1,12 +1,18 @@
+from __future__ import annotations
+
 import copy
 import sys
+from dataclasses import InitVar, dataclass, field
 from importlib import import_module
+from typing import TYPE_CHECKING, Type
 
 from django.apps import apps as django_apps
 from django.core.management.color import color_style
 from django.utils.module_loading import module_has_submodule
-from edc_notification import AlreadyRegistered as NotificationAlreadyRegistered
-from edc_notification import site_notifications
+from edc_notification.site_notifications import (
+    AlreadyRegistered as NotificationAlreadyRegistered,
+)
+from edc_notification.site_notifications import site_notifications
 from edc_prn.prn import Prn
 from edc_prn.site_prn_forms import AlreadyRegistered as PrnAlreadyRegistered
 from edc_prn.site_prn_forms import site_prn_forms
@@ -14,6 +20,10 @@ from edc_prn.site_prn_forms import site_prn_forms
 from .create_or_update_action_type import create_or_update_action_type
 from .get_action_type import get_action_type
 
+if TYPE_CHECKING:
+    from .action import Action
+    from .action_with_notification import ActionWithNotification
+
 
 class AlreadyRegistered(Exception):
     pass
@@ -23,10 +33,23 @@ class SiteActionError(Exception):
     pass
 
 
+@dataclass
+class ActionButton:
+    action_cls: InitVar[Type[Action] | Type[ActionWithNotification]] = None
+    name: str = field(init=False)
+    display_name: str = field(init=False)
+    action_type_id: str = field(init=False)
+
+    def __post_init__(self, action_cls: Type[Action] | Type[ActionWithNotification]):
+        self.name = action_cls.name
+        self.display_name = action_cls.display_name
+        self.action_type_id = str(get_action_type(action_cls).pk)
+
+
 class SiteActionItemCollection:
     def __init__(self):
-        self.registry = {}
-        self.updated_action_types = None
+        self.registry: dict[str, Type[Action] | Type[ActionWithNotification]] = {}
+        self.updated_action_types: bool | None = None
         prn = Prn(model="edc_action_item.actionitem", url_namespace="edc_action_item_admin")
         site_prn_forms.register(prn)
 
@@ -39,7 +62,16 @@ class SiteActionItemCollection:
     def __iter__(self):
         return iter(self.registry.values())
 
-    def register(self, action_cls=None):
+    def unregister(self, action_cls: Type[Action] | Type[ActionWithNotification]) -> None:
+        if action_cls.name in self.registry:
+            del self.registry[action_cls.name]
+            prn = Prn(
+                model=action_cls.get_reference_model(),
+                url_namespace=action_cls.admin_site_name,
+            )
+            site_prn_forms.unregister(prn)
+
+    def register(self, action_cls: Type[Action] | Type[ActionWithNotification] = None) -> None:
         if action_cls.name in self.registry:
             raise AlreadyRegistered(
                 f"Action class is already registered. Got name='{action_cls.name}' "
@@ -64,7 +96,7 @@ class SiteActionItemCollection:
             self.register_notifications(action_cls)
 
     @staticmethod
-    def register_notifications(action_cls):
+    def register_notifications(action_cls: Type[Action] | Type[ActionWithNotification]):
         """Registers a new model notification and an updated model
         notification for this action cls.
 
@@ -76,7 +108,11 @@ class SiteActionItemCollection:
             except NotificationAlreadyRegistered:
                 pass
 
-    def get(self, name):
+    @property
+    def all(self) -> dict[str, Type[Action] | Type[ActionWithNotification]]:
+        return self.registry
+
+    def get(self, name) -> Type[Action] | Type[ActionWithNotification]:
         """Returns an action class."""
         if name not in self.registry:
             raise SiteActionError(
@@ -85,24 +121,22 @@ class SiteActionItemCollection:
             )
         return self.registry.get(name)
 
-    def get_by_model(self, model=None):
+    def get_by_model(self, model=None) -> Type[Action] | Type[ActionWithNotification] | None:
         """Returns the action_cls linked to this reference model."""
         for action_cls in self.registry.values():
             if action_cls.get_reference_model() == model:
                 return self.get(action_cls.name)
         return None
 
-    def get_show_link_to_add_actions(self):
-        class Wrapper:
-            def __init__(self, action_cls=None):
-                self.name = action_cls.name
-                self.display_name = action_cls.display_name
-                self.action_type_id = str(get_action_type(action_cls).pk)
+    def get_add_actions_to_show(self) -> dict[str, Type[Action]]:
+        actions = {
+            action_cls.name: action_cls
+            for action_cls in self.registry.values()
+            if action_cls.show_link_to_add
+        }
+        return actions
 
-        names = [v.name for v in self.registry.values() if v.show_link_to_add]
-        return [Wrapper(action_cls=self.get(name)) for name in names]
-
-    def create_or_update_action_types(self):
+    def create_or_update_action_types(self) -> None:
         """Populates the ActionType model."""
         for action_cls in self.registry.values():
             create_or_update_action_type(**action_cls.as_dict())
@@ -122,7 +156,7 @@ class SiteActionItemCollection:
                 try:
                     before_import_registry = copy.copy(site_action_items.registry)
                     import_module(f"{app}.{module_name}")
-                    writer(f" * registered '{module_name}' from '{app}'\n")
+                    writer(f"   - registered '{module_name}' from '{app}'\n")
                 except SiteActionError as e:
                     writer(f"   - loading {app}.{module_name} ... ")
                     writer(style.ERROR(f"ERROR! {e}\n"))
@@ -135,7 +169,7 @@ class SiteActionItemCollection:
             except Exception as e:
                 raise SiteActionError(
                     f"{e.__class__.__name__} was raised when loading {module_name}. "
-                    f"Got {e} See {app}.{module_name}"
+                    f'Got "{e}" See {app}.{module_name}'
                 )
 
 
