@@ -2,23 +2,52 @@ from typing import Any
 
 from django.db import models
 from django.db.models.deletion import CASCADE, PROTECT
+from edc_consent.field_mixins import PersonalFieldsMixin
+from edc_consent.model_mixins import ConsentModelMixin
 from edc_constants.choices import YES_NO
 from edc_constants.constants import YES
 from edc_crf.model_mixins import CrfWithActionModelMixin
-from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
+from edc_identifier.model_mixins import (
+    NonUniqueSubjectIdentifierFieldMixin,
+    NonUniqueSubjectIdentifierModelMixin,
+)
 from edc_model.models import BaseUuidModel, HistoricalRecords
-from edc_sites.models import SiteModelMixin
+from edc_sites.model_mixins import SiteModelMixin
+from edc_visit_schedule.model_mixins import OffScheduleModelMixin, OnScheduleModelMixin
 
 from ..models import ActionModelMixin
 
 
+class OnSchedule(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):
+    pass
+
+
+class OffSchedule(SiteModelMixin, OffScheduleModelMixin, BaseUuidModel):
+    pass
+
+
+class SubjectConsent(
+    ConsentModelMixin,
+    SiteModelMixin,
+    NonUniqueSubjectIdentifierModelMixin,
+    PersonalFieldsMixin,
+    BaseUuidModel,
+):
+    screening_identifier = models.CharField(
+        verbose_name="Screening identifier", max_length=50, unique=True
+    )
+    history = HistoricalRecords()
+
+    class Meta(ConsentModelMixin.Meta):
+        pass
+
+
 class SubjectIdentifierModelManager(models.Manager):
     def get_by_natural_key(self, subject_identifier):
         return self.get(subject_identifier=subject_identifier)
 
 
 class SubjectIdentifierModel(NonUniqueSubjectIdentifierFieldMixin, BaseUuidModel):
-
     objects = SubjectIdentifierModelManager()
 
     history = HistoricalRecords()
@@ -26,9 +55,11 @@ class SubjectIdentifierModel(NonUniqueSubjectIdentifierFieldMixin, BaseUuidModel
     def natural_key(self):
         return (self.subject_identifier,)  # noqa
 
+    class Meta(BaseUuidModel.Meta, NonUniqueSubjectIdentifierFieldMixin.Meta):
+        pass
+
 
 class TestModelWithoutMixin(BaseUuidModel):
-
     subject_identifier = models.CharField(max_length=25)
     history = HistoricalRecords()
 
@@ -39,7 +70,6 @@ class TestModelWithActionDoesNotCreateAction(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "test-nothing-prn-action"
 
 
@@ -49,7 +79,6 @@ class TestModelWithAction(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-form-zero"
 
 
@@ -59,7 +88,6 @@ class FormZero(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-form-zero"
 
     f1 = models.CharField(max_length=100, null=True)
@@ -71,7 +99,6 @@ class FormOne(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-form-one"
 
     f1 = models.CharField(max_length=100, null=True)
@@ -83,7 +110,6 @@ class FormTwo(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     form_one = models.ForeignKey(FormOne, on_delete=PROTECT)
 
     action_name = "submit-form-two"
@@ -95,7 +121,6 @@ class FormThree(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-form-three"
 
 
@@ -105,7 +130,6 @@ class FormFour(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-form-four"
 
     happy = models.CharField(max_length=10, choices=YES_NO, default=YES)
@@ -117,7 +141,6 @@ class Initial(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "submit-initial"
 
 
@@ -127,7 +150,6 @@ class Followup(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     initial = models.ForeignKey(Initial, on_delete=CASCADE)
 
     action_name = "submit-followup"
@@ -139,14 +161,12 @@ class MyAction(
     SiteModelMixin,
     BaseUuidModel,
 ):
-
     action_name = "my-action"
 
 
 class CrfOne(ActionModelMixin, SiteModelMixin, BaseUuidModel):
-
     subject_visit = models.OneToOneField(
-        "edc_metadata.subjectvisit",  # noqa
+        "edc_visit_tracking.subjectvisit",  # noqa
         on_delete=CASCADE,
         related_name="edc_action_item_test_visit_one",
     )
@@ -167,9 +187,8 @@ class CrfOne(ActionModelMixin, SiteModelMixin, BaseUuidModel):
 
 
 class CrfTwo(ActionModelMixin, SiteModelMixin, BaseUuidModel):
-
     subject_visit = models.OneToOneField(
-        "edc_metadata.subjectvisit",  # noqa
+        "edc_visit_tracking.subjectvisit",  # noqa
         on_delete=CASCADE,
         related_name="edc_action_item_test_visit_two",
     )
