@@ -3,7 +3,6 @@ from django.test import TestCase
 from edc_constants.constants import CLOSED, NEW, NO, YES
 
 from edc_action_item.get_action_type import get_action_type
-from edc_action_item.helpers import ActionItemHelper
 from edc_action_item.models import ActionItem, ActionType
 from edc_action_item.site_action_items import site_action_items
 
@@ -103,7 +102,6 @@ class TestAction(TestCaseMixin, TestCase):
         self.assertEqual(get_action_type(action), action_type)
 
     def test_check_attrs_for_form_one_next_action(self):
-
         form_one = FormOne.objects.create(subject_identifier=self.subject_identifier)
 
         action_type_two = get_action_type(site_action_items.get(FormTwo.action_name))
@@ -290,7 +288,6 @@ class TestAction(TestCaseMixin, TestCase):
         FormThree.objects.create(subject_identifier=self.subject_identifier)
 
     def test_action_is_closed_if_model_creates_action(self):
-
         # form_one next_actions = [FormTwoAction, FormThreeAction]
         form_one_obj = FormOne.objects.create(subject_identifier=self.subject_identifier)
         self.assertEqual(ActionItem.objects.all().count(), 3)
@@ -340,57 +337,7 @@ class TestAction(TestCaseMixin, TestCase):
         )
         self.assertEqual(obj.status, CLOSED)
 
-    def test_reference_url(self):
-        action = FormOneAction(subject_identifier=self.subject_identifier)
-        helper = ActionItemHelper(action_item=action.action_item)
-        url = helper.get_url(model_cls=action.reference_model_cls())
-        self.assertEqual(
-            url,
-            (
-                f"/admin/edc_action_item/formone/add/?"
-                f"action_identifier={action.action_identifier}"
-            ),
-        )
-
-    def test_reference_url2(self):
-        form_one = FormOne.objects.create(subject_identifier=self.subject_identifier)
-        helper = ActionItemHelper(
-            action_name=FormTwoAction.name, related_action_item=form_one.action_item
-        )
-        form_two_add_url = helper.reference_url
-        self.assertEqual(
-            form_two_add_url,
-            f"/admin/edc_action_item/formtwo/add/?form_one={str(form_one.pk)}",
-        )
-        form_two = FormTwo.objects.create(
-            subject_identifier=self.subject_identifier, form_one=form_one
-        )
-        helper = ActionItemHelper(action_item=form_two.action_item)
-        form_two_change_url = helper.reference_url
-        self.assertEqual(
-            form_two_change_url,
-            f"/admin/edc_action_item/formtwo/{str(form_two.pk)}/change/?"
-            f"action_identifier={form_two.action_identifier}&form_one={str(form_one.pk)}",
-        )
-
-    def test_reference_url3(self):
-        form_one = FormOne.objects.create(subject_identifier=self.subject_identifier)
-        form_two_action = FormTwoAction(
-            subject_identifier=self.subject_identifier,
-            related_action_item=form_one.action_item,
-        )
-        helper = ActionItemHelper(action_item=form_two_action.action_item)
-        self.assertEqual(
-            helper.reference_url,
-            (
-                f"/admin/edc_action_item/formtwo/add/?"
-                f"action_identifier={form_two_action.action_identifier}&"
-                f"form_one={str(form_one.pk)}"
-            ),
-        )
-
     def test_create_singleton(self):
-
         action1 = SingletonAction(subject_identifier=self.subject_identifier)
 
         try:
@@ -426,7 +373,6 @@ class TestAction(TestCaseMixin, TestCase):
         self.assertEqual(action_item.status, NEW)
 
     def test_add_action_if_required(self):
-
         FormFourAction(subject_identifier=self.subject_identifier)
         form_four = FormFour.objects.create(
             subject_identifier=self.subject_identifier, happy=YES
