@@ -1,13 +1,17 @@
+from dateutil.relativedelta import relativedelta
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models.deletion import ProtectedError
 from django.test import TestCase
-from edc_constants.constants import CLOSED, NEW, OPEN
+from edc_consent.tests.consent_test_utils import consent_definition_factory
+from edc_constants.constants import CANCELLED, CLOSED, NEW, OPEN
+from edc_utils import get_utcnow
 
 from edc_action_item.action import Action
 from edc_action_item.create_or_update_action_type import create_or_update_action_type
+from edc_action_item.exceptions import ActionItemStatusError, SubjectDoesNotExist
 from edc_action_item.forms import ActionItemForm
 from edc_action_item.get_action_type import get_action_type
-from edc_action_item.models import ActionItem, ActionType, SubjectDoesNotExist
+from edc_action_item.models import ActionItem, ActionType
 from edc_action_item.site_action_items import site_action_items
 
 from ..action_items import FormOneAction, FormThreeAction, FormTwoAction, FormZeroAction
@@ -16,8 +20,16 @@ from ..test_case_mixin import TestCaseMixin
 
 
 class TestActionItem(TestCaseMixin, TestCase):
+    @classmethod
+    def setUpTestData(cls):
+        consent_definition_factory(
+            model="edc_action_item.subjectconsent",
+            start=get_utcnow() - relativedelta(years=1),
+            end=get_utcnow() + relativedelta(years=1),
+        )
+
     def setUp(self):
-        self.subject_identifier = self.fake_enroll()
+        self.subject_identifier = self.enroll()
         site_action_items.registry = {}
         site_action_items.register(FormZeroAction)
         get_action_type(FormZeroAction)
@@ -27,11 +39,11 @@ class TestActionItem(TestCaseMixin, TestCase):
         obj = ActionItem.objects.create(
             subject_identifier=self.subject_identifier,
             action_type=self.action_type,
-            reference_model="edc_action_item.testmodel",
         )
         self.assertTrue(obj.action_identifier.startswith("AC"))
         self.assertEqual(obj.status, NEW)
         self.assertIsNotNone(obj.report_datetime)
+        self.assertEqual(obj.action_type.reference_model, "edc_action_item.formzero")
 
     def test_create_requires_existing_subject(self):
         self.assertRaises(SubjectDoesNotExist, ActionItem.objects.create)
@@ -74,7 +86,6 @@ class TestActionItem(TestCaseMixin, TestCase):
             self.fail("ActionItem unexpectedly does not exist")
 
     def test_changes_action_item_status_from_new_to_open_on_edit(self):
-
         action_type = ActionType.objects.get(name=FormZeroAction.name)
 
         obj = ActionItem.objects.create(
@@ -318,3 +329,22 @@ class TestActionItem(TestCaseMixin, TestCase):
         self.assertEqual(form_two.action_item.status, OPEN)
         self.assertEqual(form_three.action_item.status, OPEN)
         self.assertEqual(form_one.action_item.status, CLOSED)
+
+    def test_cannot_cancel_if_reference_obj_exists(self):
+        site_action_items.register(FormOneAction)
+        site_action_items.register(FormTwoAction)
+        site_action_items.register(FormThreeAction)
+
+        form_one_action = FormOneAction(subject_identifier=self.subject_identifier)
+        form_one = FormOne.objects.create(
+            subject_identifier=self.subject_identifier,
+            action_identifier=form_one_action.action_identifier,
+        )
+        form_one.f1 = "blah"
+        form_one.save()
+
+        form_one.refresh_from_db()
+        self.assertEqual(form_one.action_item.status, CLOSED)
+
+        form_one.action_item.status = CANCELLED
+        self.assertRaises(ActionItemStatusError, form_one.action_item.save)
