@@ -3,7 +3,7 @@ from unittest.case import skip
 from django.core import mail
 from django.test import TestCase
 from edc_constants.constants import NEW
-from edc_notification import NewModelNotification, UpdatedModelNotification
+from edc_notification.notification import NewModelNotification, UpdatedModelNotification
 from edc_notification.site_notifications import site_notifications
 
 from edc_action_item.action_item_notification import (
@@ -23,7 +23,6 @@ class TestActionNotification(TestCaseMixin, TestCase):
         self.subject_identifier = self.fake_enroll()
 
     def test_sends_correct_number_of_emails(self):
-
         self.assertIn(FormZeroAction, site_action_items.registry.values())
 
         # action without reference obj
