@@ -1,11 +1,11 @@
 from importlib import import_module
 
 from django.test import TestCase, override_settings
-from edc_adverse_event.auth_objects import TMG_ROLE
+from edc_adverse_event.constants import TMG_ROLE
 from edc_auth.auth_updater import AuthUpdater
 from edc_auth.site_auths import site_auths
 from edc_data_manager.auth_objects import DATA_MANAGER_ROLE, SITE_DATA_MANAGER_ROLE
-from edc_export.auth_objects import EXPORT
+from edc_export.constants import EXPORT
 
 
 class TestAuths(TestCase):
