@@ -1,7 +1,11 @@
 from dateutil.relativedelta import relativedelta
-from edc_visit_schedule import Crf, FormsCollection, Schedule, Visit, VisitSchedule
+from edc_visit_schedule.schedule import Schedule
+from edc_visit_schedule.visit import Crf, CrfCollection, Visit
+from edc_visit_schedule.visit_schedule import VisitSchedule
 
-crfs = FormsCollection(
+from .consents import consent_v1
+
+crfs = CrfCollection(
     Crf(show_order=1, model="edc_action_item.crflongitudinalone", required=True),
     Crf(show_order=2, model="edc_action_item.crflongitudinaltwo", required=True),
 )
@@ -37,9 +41,9 @@ visit1 = Visit(
 
 schedule = Schedule(
     name="schedule",
-    onschedule_model="edc_metadata.onschedule",
-    offschedule_model="edc_metadata.offschedule",
-    consent_model="edc_metadata.subjectconsent",
+    onschedule_model="edc_visit_schedule.onschedule",
+    offschedule_model="edc_visit_schedule.offschedule",
+    consent_definitions=[consent_v1],
     appointment_model="edc_appointment.appointment",
 )
 
