@@ -1,9 +1,8 @@
-from edc_visit_schedule import site_visit_schedules
 from edc_visit_schedule.models import SubjectScheduleHistory
+from edc_visit_schedule.site_visit_schedules import site_visit_schedules
 
 
 class VisitScheduleActionMixin:
-
     """A mixin for the Action class to add properties and
     methods related to the visit schedule from
     edc_visit_schedule.
