@@ -1,28 +1,29 @@
 #!/usr/bin/env python
 import logging
-import os
-import sys
-from os.path import abspath, dirname
+from pathlib import Path
 
-import django
-from django.conf import settings
-from django.test.runner import DiscoverRunner
-from edc_constants.constants import IGNORE
-from edc_test_utils import DefaultTestSettings
+from edc_test_utils import DefaultTestSettings, func_main
 
 app_name = "edc_action_item"
-base_dir = dirname(abspath(__file__))
+base_dir = Path(__file__).absolute().parent
 
-DEFAULT_SETTINGS = DefaultTestSettings(
+project_settings = DefaultTestSettings(
     calling_file=__file__,
     BASE_DIR=base_dir,
     APP_NAME=app_name,
-    ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
-    SUBJECT_VISIT_MODEL="edc_metadata.subjectvisit",
+    ETC_DIR=str(base_dir / app_name / "tests" / "etc"),
+    EMAIL_ENABLED=True,
+    SILENCED_SYSTEM_CHECKS=[
+        "edc_consent.E001",
+        "sites.E101",
+        "edc_navbar.E002",
+        "edc_navbar.E003",
+    ],
+    SUBJECT_VISIT_MODEL="edc_visit_tracking.subjectvisit",
     SUBJECT_VISIT_MISSED_MODEL="edc_metadata.subjectvisitmissed",
-    EDC_NAVBAR_VERIFY_ON_LOAD=IGNORE,
     EDC_AUTH_SKIP_SITE_AUTHS=True,
     EDC_AUTH_SKIP_AUTH_UPDATER=True,
+    EDC_SITES_REGISTER_DEFAULT=True,
     INSTALLED_APPS=[
         "django.contrib.admin",
         "django.contrib.auth",
@@ -33,48 +34,41 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "django.contrib.sites",
         "django_crypto_fields.apps.AppConfig",
         "django_revision.apps.AppConfig",
-        # "rest_framework",
-        # "rest_framework.authtoken",
-        # "django_collect_offline.apps.AppConfig",
-        # "django_collect_offline_files.apps.AppConfig",
         "simple_history",
         "multisite",
+        "edc_sites.apps.AppConfig",
         "edc_auth.apps.AppConfig",
         "edc_appointment.apps.AppConfig",
         "edc_crf.apps.AppConfig",
+        "edc_data_manager.apps.AppConfig",
+        "edc_form_runners.apps.AppConfig",
         "edc_facility.apps.AppConfig",
         "edc_lab.apps.AppConfig",
         "edc_navbar.apps.AppConfig",
         "edc_offstudy.apps.AppConfig",
-        "edc_reference.apps.AppConfig",
         "edc_metadata.apps.AppConfig",
         "edc_protocol.apps.AppConfig",
         "edc_identifier.apps.AppConfig",
         "edc_device.apps.AppConfig",
         "edc_fieldsets.apps.AppConfig",
+        "edc_list_data.apps.AppConfig",
         "edc_notification.apps.AppConfig",
         "edc_randomization.apps.AppConfig",
         "edc_registration.apps.AppConfig",
         "edc_timepoint.apps.AppConfig",
-        "edc_sites.apps.AppConfig",
+        "edc_subject_dashboard.apps.AppConfig",
         "edc_visit_tracking.apps.AppConfig",
         "edc_visit_schedule.apps.AppConfig",
         "edc_action_item.apps.AppConfig",
+        "edc_appconfig.apps.AppConfig",
     ],
     add_dashboard_middleware=True,
-    # add_lab_dashboard_middleware=True,
     use_test_urls=True,
 ).settings
 
 
 def main():
-    if not settings.configured:
-        settings.configure(**DEFAULT_SETTINGS)
-    django.setup()
-    tags = [t.split("=")[1] for t in sys.argv if t.startswith("--tag")]
-    failfast = any([True for t in sys.argv if t.startswith("--failfast")])
-    failures = DiscoverRunner(failfast=failfast, tags=tags).run_tests([f"{app_name}.tests"])
-    sys.exit(failures)
+    func_main(project_settings, f"{app_name}.tests")
 
 
 if __name__ == "__main__":
